/* from blueprint */
div, span, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, code,
del, dfn, em, img, q, dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, dialog, figure, footer, header,
hgroup, nav, section, hr {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline; }

/* This helps to make newer HTML5 elements behave like DIVs in older browers */
article, aside, details, figcaption, figure, dialog,
footer, header, hgroup, menu, nav, section {
  display: block; }

/* Line-height should always be unitless! */
body {
  line-height: 1.5;
  background: white; }

/* Tables still need 'cellspacing="0"' in the markup. */
table {
  border-collapse: separate;
  border-spacing: 0; }

/* float:none prevents the span-x classes from breaking table-cell display */
caption, th, td {
  text-align: left;
  font-weight: normal;
  float: none !important; }

table, th, td {
  vertical-align: middle; }

/* Remove possible quote marks (") from <q>, <blockquote>. */
blockquote:before, blockquote:after, q:before, q:after {
  content: ''; }

blockquote, q {
  quotes: "" ""; }

/* Remove annoying border on linked images. */
a img {
  border: none; }

/* Remember to define your own focus styles! */
:focus {
  outline: 0; }

hr {
  color: #ccc;
  background: #ccc;
  height: 1px;
  border: 0;
  margin: 0 0 1.5em; }

/* typography update */
html {
  font-size: 100.01%; }

body {
  font-size: 75%;
  color: #333;
  background: #fff;
  font-family: "Helvetica Neue", Arial, Helvetica, sans-serif; }

/* Headings
-------------------------------------------------------------- */
h1, h2, h3, h4, h5, h6 {
  font-weight: normal;
  color: #111; }

h1 {
  font-size: 3em;
  line-height: 1;
  margin-bottom: 0.5em; }

h2 {
  font-size: 2em;
  margin-bottom: 0.75em; }

h3 {
  font-size: 1.5em;
  line-height: 1;
  margin-bottom: 1em; }

h4 {
  font-size: 1.2em;
  line-height: 1.25;
  margin-bottom: 1.25em; }

h5 {
  font-size: 1em;
  font-weight: bold;
  margin-bottom: 1.5em; }

h6 {
  font-size: 1em;
  font-weight: bold; }

h1 img, h2 img, h3 img,
h4 img, h5 img, h6 img {
  margin: 0; }

/* Text elements
-------------------------------------------------------------- */
p {
  margin: 0 0 1.5em; }

/*
  These can be used to pull an image at the start of a paragraph, so
  that the text flows around it (usage: <p><img class="left">Text</p>)
 */
.left {
  float: left !important; }

p .left {
  margin: 1.5em 1.5em 1.5em 0;
  padding: 0; }

.right {
  float: right !important; }

p .right {
  margin: 1.5em 0 1.5em 1.5em;
  padding: 0; }

a:focus,
a:hover {
  color: #09f; }

a {
  color: #06c;
  text-decoration: underline; }

blockquote {
  margin: 1.5em;
  color: #666;
  font-style: italic; }

strong, dfn {
  font-weight: bold; }

em, dfn {
  font-style: italic; }

sup, sub {
  line-height: 0; }

abbr,
acronym {
  border-bottom: 1px dotted #666; }

address {
  margin: 0 0 1.5em;
  font-style: italic; }

del {
  color: #666; }

pre {
  margin: 1.5em 0;
  white-space: pre; }

pre, code, tt {
  font: 1em 'andale mono', 'lucida console', monospace;
  line-height: 1.5; }

hr {
  color: #ccc;
  background: #ccc;
  height: 1px;
  border: 0;
  margin: 0 0 1.25em; }

/* Lists
-------------------------------------------------------------- */
li ul,
li ol {
  margin: 0; }

ul, ol {
  margin: 0 1.5em 1.5em 0;
  padding-left: 1.5em; }

ul {
  list-style-type: disc; }

ol {
  list-style-type: decimal; }

dl {
  margin: 0 0 1.5em 0; }

dl dt {
  font-weight: bold; }

dd {
  margin-left: 1.5em; }

/* Tables
-------------------------------------------------------------- */
/*
  Because of the need for padding on TH and TD, the vertical rhythm
  on table cells has to be 27px, instead of the standard 18px or 36px
  of other elements.
 */
table {
  margin-bottom: 1.4em;
  width: 100%; }

th {
  font-weight: bold; }

thead th {
  background: #c3d9ff; }

th, td, caption {
  padding: 4px 10px 4px 5px; }

/*
  You can zebra-stripe your tables in outdated browsers by adding
  the class "even" to every other table row.
 */
tbody tr:nth-child(even) td,
tbody tr.even td {
  background: #e5ecf9; }

tfoot {
  font-style: italic; }

caption {
  background: #eee; }

body {
  background: #f7f7f7; }

.wrapper {
  max-width: 960px;
  margin: 0 auto; }
