{% extends "helpdesk/inner.html" %}
{% load i18n %}
{% load url from future %}

{% block helpdesk_widgets %}
    <div class="dk-widget">
        <h3>{% trans "View a Ticket" %}</h3>
        <hr />
        <form method='get' action="{% url 'helpdesk_public_view' %}">
            {% if error_message %}<p class="error">{{ error_message }}</p>{% endif %}
            <fieldset>
                <dl>
                    <dt><label for='id_ticket'>{% trans "Ticket" %}</label></dt>
                    <dd><input type='text' name='ticket' /></dd>
            
                    <dt><label for='id_email'>{% trans "Your E-mail Address" %}</label></dt>
                    <dd><input type='text' name='email' /></dd>
                </dl>
                <input type='submit' value='{% trans "View Ticket" %}' />
            </fieldset>
            {% csrf_token %}
        </form>
    </div>
{% endblock %}
