{% extends "helpdesk/inner.html" %}
{% load i18n %}

{% block helpdesk_title %}{% trans "Create Ticket" %}{% endblock %}

{% block helpdesk_widgets %}
    <div class="dk-widget">
        <h3>{% trans "Submit a Ticket" %}</h3>
        <hr />
        <p>{% blocktrans %}Unless otherwise stated, all fields are required. Please provide as descriptive a title and description as possible.{% endblocktrans %}</p>
		<form method='post' action='./' enctype='multipart/form-data'>
			<fieldset>
			    <dl>
			        {% for field in form %}
			            {% if field.is_hidden %}
			                {{ field }}
			            {% else %}
			                <dt><label for='id_{{ field.name }}'>{% trans field.label %}</label>{% if not field.field.required %} <span class='form_optional'>{% trans "(Optional)" %}</span>{% endif %}</dt>
			                <dd>{{ field }}</dd>
			                {% if field.errors %}<dd class='error'>{{ field.errors }}</dd>{% endif %}
			                {% if field.help_text %}<dd class='form_help_text'>{% trans field.help_text %}</dd>{% endif %}
			            {% endif %}
			        {% endfor %}
			    </dl>
			    
			    <div class='buttons'>
			        <input type='submit' value='{% trans "Submit Ticket" %}' />
			    </div>
			</fieldset>
			{% csrf_token %}
		</form>
	</div>
{% endblock %}
