{% extends "helpdesk/base.html" %}{% load i18n %}{% load url from future %}

{% block helpdesk_title %}{% trans "Add Ticket CC" %}{% endblock %}

{% block helpdesk_body %}{% blocktrans %}
<h2>Add Ticket CC</h2>

<p>To automatically send an email to a user or e-mail address when this ticket is updated, select the user or enter an e-mail address below.</p>{% endblocktrans %}

<form method='post' action='./'>

<fieldset>
    <dl>{% for field in form %}
        <dt><label for='id_{{ field.name }}'>{{ field.label }}</label></dt>
        <dd>{{ field }}</dd>
        {% if field.errors %}<dd class='error'>{{ field.errors }}</dd>{% endif %}
        {% if field.help_text %}<dd class='form_help_text'>{{ field.help_text }}</dd>{% endif %}
    {% endfor %}</dl>
</fieldset>

<input type='submit' value='{% trans "Save Ticket CC" %}' />

{% csrf_token %}</form>

{% endblock %}
