<h1 style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 14pt; color: #6593C0'>{% block header %}Техническая поддержка{% endblock %}</h1>

{% block content %}{% endblock %}

<p style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 11pt;'>С уважением,</p>

<p style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 11pt;'><b>{{ queue.title }}</b>{% if queue.email_address %}<br><a href='mailto:{{ queue.email_address }}'>{{ queue.email_address }}</a>{% endif %}</p>
    
<p style='font-family: "Trebuchet MS", Arial, sans-serif; font-size: 9pt; color: #808080;' color='#808080'>Это письмо было отправлено Вам, как нашему клиенту. Пожалуйста, сообщите нам, если Вы получили это письмо по ошибке.</p>
