{% load i18n %}
{% load url from future %}

<h4>{% trans "Navigate" %}</h4>
<hr />

<ul>
    <li><a href="{% url 'helpdesk_home' %}">{% trans "Return to home" %}</a></li>
    <li><a href="{% url 'helpdesk_dashboard' %}">{% trans "Return to dashboard" %}</a></li>
    <li><a href="{% url 'helpdesk_submit' %}">{% trans "Submit a ticket" %}</a></li>
    <li><a href="{% url 'helpdesk_user_settings' %}">{% trans "Settings" %}</a></li>
</ul>
