{% extends "helpdesk/base.html" %}{% load i18n %}

{% block helpdesk_title %}{% trans "Delete Saved Query" %}{% endblock %}

{% block helpdesk_body %}{% blocktrans with query.title as query_title  %}
<h2>Delete Query</h2>

<p>Are you sure you want to delete this saved filter (<em>{{ query_title }}</em>)? To re-create it, you will need to manually re-filter your ticket listing.</p>
{% endblocktrans %}

{% if query.shared %}{% blocktrans %}
<p>You have shared this query, so other users may be using it. If you delete it, they will have to manually create their own query.</p>
{% endblocktrans %}{% endif %}

<p><a href='../'>{% trans "No, Don't Delete It" %}</a></p>

<form method='post' action='./'><input type='submit' value='{% trans "Yes - Delete It" %}' />{% csrf_token %}</form>
{% endblock %}
